---
title: <span class="badge builder"></span> ExprTypeReduceTimeRange
---
# <span class="badge builder"></span> ExprTypeReduceTimeRange

## Constructor

```python
ExprTypeReduceTimeRange()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> expr.ExprTypeReduceTimeRange
```

### <span class="badge object-method"></span> from_val

From is the start time of the query.

```python
def from_val(from_val: str) -> typing.Self
```

### <span class="badge object-method"></span> to

To is the end time of the query.

```python
def to(to: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ExprTypeReduceTimeRange](./object-ExprTypeReduceTimeRange.md)
